# RPM spec file for OpenStack on RHEL 6 and 7
# Some bits borrowed from the katello-selinux package

%global selinuxtype	targeted
%global moduletype	services
%global modulenames	os-ovs os-swift os-nova os-neutron os-mysql os-glance os-rsync os-rabbitmq

# Usage: _format var format
#   Expand 'modulenames' into various formats as needed
#   Format must contain '$x' somewhere to do anything useful
%global _format() export %1=""; for x in %{modulenames}; do %1+=%2; %1+=" "; done;

# We do this in post install and post uninstall phases
%global relabel_files() \
	/sbin/restorecon -Rv %{_bindir}/swift* %{_localstatedir}/run/swift /srv %{_bindir}/neutron* &> /dev/null || :\

# Version of SELinux we were using
%global selinux_policyver 3.12.1-153.el7_0.10

# Package information
Name:			openstack-selinux
Version:		0.5.20
Release:		1%{?dist}
License:		GPLv2
Group:			System Environment/Base
Summary:		SELinux Policies for OpenStack
BuildArch:		noarch
URL:			https://github.com/redhat-openstack/%{name}
Requires:		policycoreutils, libselinux-utils
Requires(post):		selinux-policy-base >= %{selinux_policyver}, selinux-policy-targeted >= %{selinux_policyver}, policycoreutils, policycoreutils-python
Requires(postun):	policycoreutils
BuildRequires:		selinux-policy selinux-policy-devel

#
# wget -c https://github.com/lhh/%{name}/archive/%{version}.tar.gz \
#    -O %{name}-%{version}.tar.gz
#
Source:			%{name}-%{version}.tar.gz


%description
SELinux policy modules for use with OpenStack

%package test
Summary:		AVC Tests for %{name}
Requires:		policycoreutils-python, bash
Requires:		%{name} = %{version}-%{release}

%description test
AVC tests for %{name}

%prep
%setup -q

%build
make SHARE="%{_datadir}" TARGETS="%{modulenames}"

%install

# Install SELinux interfaces
%_format INTERFACES $x.if
install -d %{buildroot}%{_datadir}/selinux/devel/include/%{moduletype}
install -p -m 644 $INTERFACES \
	%{buildroot}%{_datadir}/selinux/devel/include/%{moduletype}

# Install policy modules
%_format MODULES $x.pp.bz2
install -d %{buildroot}%{_datadir}/selinux/packages
install -m 0644 $MODULES \
	%{buildroot}%{_datadir}/selinux/packages

# Test package files
install -d %{buildroot}%{_datadir}/%{name}/%{version}/tests
install -m 0644 tests/bz* %{buildroot}%{_datadir}/%{name}/%{version}/tests
install -m 0755 tests/check_all %{buildroot}%{_datadir}/%{name}/%{version}/tests

%post
#
# Install all modules in a single transaction
#
%_format MODULES %{_datadir}/selinux/packages/$x.pp.bz2
%{_sbindir}/semodule -n -s %{selinuxtype} -i $MODULES

if %{_sbindir}/selinuxenabled ; then
	%{_sbindir}/load_policy

	# bz#1107873
	%{_sbindir}/semanage port -a -t amqp_port_t -p tcp 15672 &> /dev/null

	# bz#1118859
	%{_sbindir}/semanage port -m -t mysqld_port_t -p tcp 4444

	# bz#1052971 - this should be handled by puppet, though
	%{_sbindir}/setsebool -P virt_use_fusefs on

	# bz#1111990 & 1083609
	%{_sbindir}/setsebool -P glance_use_fusefs on

	# bz#1108937
	%{_sbindir}/setsebool -P haproxy_connect_any on

	# bz#1112631
	%{_sbindir}/setsebool -P nis_enabled on

	# bz#1114581
	%{_sbindir}/setsebool -P haproxy_connect_any on

	# bz#1119400
	%{_sbindir}/setsebool -P glance_use_execmem on

	# bz#1135637
	%{_sbindir}/setsebool -P rsync_full_access on

	# bz#1135637
	%{_sbindir}/setsebool -P rsync_client on

	# bz#1119845
	%{_sbindir}/setsebool -P virt_use_execmem on

	# bz#1130212
	%{_sbindir}/setsebool -P glance_use_execmem on

	# bz#1110263
	%{_sbindir}/semanage fcontext -a -t neutron_exec_t %{_bindir}/neutron-metadata-agent
	%{_sbindir}/semanage fcontext -a -t neutron_exec_t %{_bindir}/neutron-netns-cleanup
	%{_sbindir}/semanage fcontext -a -t neutron_exec_t %{_bindir}/neutron-ns-metadata-proxy
	%relabel_files
fi


%postun
if [ $1 -eq 0 ]; then
	%{_sbindir}/semodule -n -r %{modulenames} &> /dev/null || :
	if %{_sbindir}/selinuxenabled ; then
		%{_sbindir}/load_policy
		%relabel_files
	fi
fi


%files
%defattr(-,root,root,0755)
%doc COPYING
%attr(0644,root,root) %{_datadir}/selinux/packages/*.pp.bz2
%attr(0644,root,root) %{_datadir}/selinux/devel/include/%{moduletype}/*.if

%files test
%defattr(-,root,root,0644)
%attr(0755,root,root) %{_datadir}/%{name}/%{version}/tests/check_all
%attr(0644,root,root) %{_datadir}/%{name}/%{version}/tests/bz*


%changelog
* Thu Nov 20 2014 Ryan Hallisey <rhallise@redhat.com> - 0.5.20-1
- Allow nova to connect to memcache_port_t
- Resolves: rhbz#1158213

* Fri Oct 17 2014 Lon Hohberger <lhh@redhat.com> 0.5.19-2
- Drop bad upgrade error

* Thu Oct 16 2014 Ryan Hallisey <rhallise@redhat.com> - 0.5.19-1
- Allow neutron_t to kill dnsmasq
- Resolves: rhbz#1153656

* Wed Sep 17 2014 Lon Hohberger <lhh@redhat.com> - 0.5.16-2
- Drop incorrect AVC checks (e.g. leaked FDs, or incorrect contexts)
- Allow glance to execmem/execstack until we have the proper boolean
- Resolves: rhbz#1130212

* Fri Sep 12 2014 Ryan Hallisey <rhallise@redhat.com> - 0.5.16-1
- Turn on booleans rsync_full_access and rsync_client
- Add new files os-rsync and os-rabbitmq
- Minor changes to testpolicy script
- Updated AVCs for regression testing
- Resolves: rhbz#1135637

* Wed Aug 20 2014 Ryan Hallisey <rhallise@redhat.com> - 0.5.15-1
- Turn on boolean glance_use_execmem
- Updated AVCs for regression testing
- Resolves: rhbz#1130212

* Wed Jul 23 2014 Ryan Hallisey <rhallise@redhat.com> - 0.5.14-4
- Added new tool to sort and save AVCs for regression testing
- Updated AVCs for regression testing
- Resolves:

* Wed Jul 16 2014 Ryan Hallisey <rhallise@redhat.com> - 0.5.14-3
- Port 4444 is now labeled as mysqld_port_t
- Resolves: rhbz#1118859

* Wed Jul 16 2014 Ryan Hallisey <rhallise@redhat.com> - 0.5.14-2
- Added virt_use_execmem and glance_use_execmem bools
- Resolves: rhbz#1119845 rhbz#1119400

* Tue Jul 15 2014 Ryan Hallisey <rhallise@redhat.com> - 0.5.14-1
- Allow mysqld_t to read from mysqld_safe_exec_t files
- Added glance.te file
- Add new avcs to regression test
- Resolves: rhbz#1118859 rhbz#1119151

* Mon Jul 14 2014 Ryan Hallisey <rhallise@redhat.com> - 0.5.13-1
- Allow mysqld_t to execute lsof
- Resolves: rhbz#1118859

* Tue Jul 08 2014 Ryan Hallisey <rhallise@redhat.com> - 0.5.12-1
- Allow ssh to open and getattr from nova_var_lib_t
- Resolves: rhbz#1117301

* Mon Jul 07 2014 Ryan Hallisey <rhallise@redhat.com> - 0.5.11-1
- Allow neutron_t to talk to haproxy_t
- Resolves: rhbz#1116755

* Wed Jul 02 2014 Ryan Hallisey <rhallise@redhat.com> - 0.5.10-1
- Allow neutron_t to kill haproxy_t processes
- Allow neutron_t to unmount a proc_t filesystem
- Resolves: rhbz#1115724

* Tue Jul 01 2014 Lon Hohberger <lhh@redhat.com> - 0.5.9-1
- Allow haproxy to access its configuration after transition
- Resolves: rhbz#1114254

* Tue Jul 01 2014 Lon Hohberger <lhh@redhat.com> - 0.5.8-1
- Add test subpackage
- Add domain transition to haproxy for os-neutron
- Remove cluster-mode from manual workarounds

* Tue Jul 01 2014 Lon Hohberger <lhh@redhat.com> - 0.5.7-3
- Quiet errors on upgrade in case of duplicate/new modules

* Tue Jul 01 2014 Lon Hohberger <lhh@redhat.com> - 0.5.7-2
- Add os-neutron and os-mysql to install targets

* Mon Jun 30 2014 Ryan Hallisey <rhallise@redhat.com> - 0.5.7-1
- Give mysqld_t permission to search nfs_t directories
- Allowing neutron_t to connect to all tcp ports
- Allow mysqld_t to bind and connect to tram_port
- Resolves: rhbz#1110263 rhbz#1114581 rhbz#1114254

* Fri Jun 27 2014 Ryan Hallisey <rhallise@redhat.com> - 0.5.6-1
- Allow sshd_t to read from nova_var_lib_t
- Added file os-mysql.te with new policy
- Resolves: rhbz#1113723 rhbz#1081544

* Wed Jun 25 2014 Ryan Hallisey <rhallise@redhat.com> - 0.5.5-3
- Turned on boolean haproxy_connect_any
- Resolves: rhbz#1108937

* Wed Jun 25 2014 Ryan Hallisey <rhallise@redhat.com> - 0.5.5-2
- Turned on boolean nis_enabled
- Resolves: rhbz#1112631

* Tue Jun 24 2014 Ryan Hallisey <rhallise@redhat.com> - 0.5.5-1
- Turned on boolean glance_use_fusefs
- Changes made to os-neutron to allow neutron_t to connect to httpd_port_t
- Changes made to os-nova to read initrc_var_run_t
- Resolves: rhbz#1111990 rhbz#1083609

* Mon Jun 23 2014 Ryan Hallisey <rhallise@redhat.com> - 0.5.4-1
- Added os-neutron policy 
- Changes made to os-swift to read httpd_config_t
- Resolves: rhbz#1105344 rhbz#1110263

* Tue Jun 17 2014 Lon Hohberger <lhh@redhat.com> - 0.5.2-2
- Add proper file contexts neutron-metadata-agent, neutron-netns-cleanup,
  and neutron-ns-metadata-proxy
- Drop monitoring-plugins tweaks in %post; not needed any more
- Resolves: rhbz#1110263

* Fri Jun 13 2014 Lon Hohberger <lhh@redhat.com> - 0.5.2-1
- Additional tweak for nova networking
- Resolves: rhbz#1095869

* Fri Jun 13 2014 Lon Hohberger <lhh@redhat.com> - 0.5.1-3
- Require SELinux policy from 7.0 updates
- Turn on swift and nova modules

* Fri Jun 13 2014 Lon Hohberger <lhh@redhat.com> - 0.5.1-1
- Import 0.5.1 to work around Nova network issues
- Resolves: rhbz#1095869

* Fri Jun 13 2014 Lon Hohberger <lhh@redhat.com> - 0.5.0-3
- Set check_ping to the correct context

* Fri Jun 13 2014 Lon Hohberger <lhh@redhat.com> - 0.5.0-2
- Turn on virt_use_fusefs in %post
- Resolves: rhbz#1052971

* Fri Jun 13 2014 Lon Hohberger <lhh@redhat.com> - 0.5.0-1
- Set port 15672/tcp to amqp_port_t
- Resolves: rhbz#1107873

* Thu Jun 12 2014 Lon Hohberger <lhh@redhat.com> - 0.5.0-0
- Initial build
- Resolves: rhbz#1108187

* Mon Dec 09 2013 Lon Hohberger <lhh@redhat.com> - 0.1.3-2
- Set neutron-vpn-agent to neutron_exec_t
- Require RHEL 6.5 selinux-policy
  Resolves: rhbz#1039204

* Thu Nov 14 2013 Lon Hohberger <lhh@redhat.com> - 0.1.3-1
- Remove unnecessary policy for LBaaS
- Rebase to 0.1.3
- Correct file contexts in %post for now
  Resolves: rhbz#1020052

* Tue Nov 12 2013 Lon Hohberger <lhh@redhat.com> - 0.1.2-13
- Additional policy additions for LBaaS
  Resolves: rhbz#1020052

* Fri Nov 08 2013 Lon Hohberger <lhh@redhat.com> - 0.1.2-12
- Add Neutron LBaaS tunable
  Resolves: rhbz#1020052

* Wed Mar 20 2013 Lon Hohberger <lhh@redhat.com> - 0.1.2-11
- Add BuildRequires for selinux-policy-devel
- Fix directory permissions

* Wed Mar 20 2013 Lon Hohberger <lhh@redhat.com> - 0.1.2-10
- Depend on later release of selinux-policy since it contains
  fixes for OpenStack Swift's use of GlusterFS 
  Resolves: rhbz#923426

* Tue Mar 19 2013 Lon Hohberger <lhh@redhat.com> - 0.1.2-9
- Depend on later release of selinux-policy since it contains
  fixes for OpenStack Quantum
  Resolves: rhbz#923426

* Mon Mar 18 2013 Lon Hohberger <lhh@redhat.com> - 0.1.2-8
- Call restorecon on /srv to ensure that previously-created
  Swift objects have the correct SELinux context
  Resolves: rhbz#918721

* Wed Mar 06 2013 Lon Hohberger <lhh@redhat.com> - 0.1.2-7
- Add a type and path for swift when using rsync
  Resolves: rhbz#918721

* Tue Mar 05 2013 Lon Hohberger <lhh@redhat.com> - 0.1.2-6
- Allow dnsmasq_t to write to quantum's DHCP directory
  Resolves: rhbz#915906

* Fri Feb 22 2013 Lon Hohberger <lhh@redhat.com> - 0.1.2-5
- Allow rsync to deal with lock files
  Resolves: rhbz#885529

* Thu Feb 21 2013 Lon Hohberger <lhh@redhat.com> - 0.1.2-4
- Fix up changelog for wrong bug
- Ancillary patch for dnsmasq AVC denial
- Resolves: rhbz#889782

* Tue Feb 12 2013 Lon Hohberger <lhh@redhat.com> - 0.1.2-3
- Spec file cleanups

* Tue Feb 12 2013 Lon Hohberger <lhh@redhat.com> - 0.1.2-2
- Spec file cleanups 

* Tue Feb 12 2013 Lon Hohberger <lhh@redhat.com> - 0.1.2-1
- Add policy for swift to resolve rsync issues
- Resolves: rhbz#885529

* Tue Feb 12 2013 Lon Hohberger <lhh@redhat.com> - 0.1.1-1
- Add policy for quantum to resolve DHCP lease issues
- Resolves: rhbz#889782

* Mon Feb 11 2013 Lon Hohberger <lhh@redhat.com> - 0.1.0-2
- Fix URL and Source identifiers

* Mon Feb 11 2013 Lon Hohberger <lhh@redhat.com> - 0.1.0-1
- First Build, addreses openstack nova issues
- Resolves: rhbz#913197
